@@ -333,6 +333,7 @@ impl State {
 
 bitflags! {
     /// Flag set.
+    #[derive(Debug, Copy, Clone, PartialEq, Eq)]
     #[repr(transparent)]
     pub struct FlagSet: u32 {
         /// Flag to pass when no specific options are needed.
@@ -498,171 +499,6 @@ impl Default for FlagSet {
     }
 }
 
-/// Some special flags for stream connections.
-#[deprecated(since = "2.20.0", note = "Use the associated constants on `FlagSet`.")]
-pub mod flags {
-    use super::FlagSet;
-
-    /// Flag to pass when no specific options are needed.
-    pub const NOFLAGS: FlagSet = FlagSet::NOFLAGS;
-
-    /// Create the stream corked, requiring an explicit [`Stream::uncork()`] call to uncork it.
-    ///
-    /// [`Stream::uncork()`]: ../struct.Stream.html#method.uncork
-    pub const START_CORKED: FlagSet = FlagSet::START_CORKED;
-
-    /// Interpolate the latency for this stream. When enabled, [`Stream::get_latency()`] and
-    /// [`Stream::get_time()`] will try to estimate the current record/playback time based on the
-    /// local time that passed since the last timing info update. Using this option has the
-    /// advantage of not requiring a whole round trip when the current playback/recording time is
-    /// needed. Consider using this option when requesting latency information frequently. This is
-    /// especially useful on long latency network connections. It makes a lot of sense to combine
-    /// this option with [`AUTO_TIMING_UPDATE`].
-    ///
-    /// [`Stream::get_latency()`]: ../struct.Stream.html#method.get_latency
-    /// [`Stream::get_time()`]: ../struct.Stream.html#method.get_time
-    pub const INTERPOLATE_TIMING: FlagSet = FlagSet::INTERPOLATE_TIMING;
-
-    /// Don’t force the time to increase monotonically. If this option is enabled,
-    /// [`Stream::get_time()`] will not necessarily return always monotonically increasing time
-    /// values on each call. This may confuse applications which cannot deal with time going
-    /// ‘backwards’, but has the advantage that bad transport latency estimations that caused the
-    /// time to jump ahead can be corrected quickly, without the need to wait.
-    ///
-    /// [`Stream::get_time()`]: super::Stream::get_time
-    pub const NOT_MONOTONIC: FlagSet = FlagSet::NOT_MONOTONIC;
-
-    /// If set timing update requests are issued periodically automatically. Combined with
-    /// [`INTERPOLATE_TIMING`] you will be able to query the current time and latency with
-    /// [`Stream::get_time()`] and [`Stream::get_latency()`] at all times without a packet round
-    /// trip.
-    ///
-    /// [`Stream::get_time()`]: super::Stream::get_time
-    /// [`Stream::get_latency()`]: super::Stream::get_latency
-    pub const AUTO_TIMING_UPDATE: FlagSet = FlagSet::AUTO_TIMING_UPDATE;
-
-    /// Don’t remap channels by their name, instead map them simply by their index. Implies
-    /// [`NO_REMIX_CHANNELS`](constant.NO_REMIX_CHANNELS.html).
-    pub const NO_REMAP_CHANNELS: FlagSet = FlagSet::NO_REMAP_CHANNELS;
-
-    /// When remapping channels by name, don’t upmix or downmix them to related channels. Copy them
-    /// into matching channels of the device 1:1.
-    pub const NO_REMIX_CHANNELS: FlagSet = FlagSet::NO_REMIX_CHANNELS;
-
-    /// Use the sample format of the sink/device this stream is being connected to, and possibly
-    /// ignore the format the sample spec contains -- but you still have to pass a valid value in it
-    /// as a hint to PulseAudio what would suit your stream best. If this is used you should query
-    /// the used sample format after creating the stream by using [`Stream::get_sample_spec()`].
-    /// Also, if you specified manual buffer metrics it is recommended to update them with
-    /// [`Stream::set_buffer_attr()`] to compensate for the changed frame sizes.
-    ///
-    /// When creating streams with [`Stream::new_extended()`], this flag has no effect. If you
-    /// specify a format with PCM encoding, and you want the server to choose the sample format,
-    /// then you should leave the sample format unspecified in the [`Info`] object. This also means
-    /// that you can’t use [`Info::new_from_sample_spec()`], because that function always sets the
-    /// sample format.
-    ///
-    /// [`Stream::get_sample_spec()`]: super::Stream::get_sample_spec
-    /// [`Stream::set_buffer_attr()`]: super::Stream::set_buffer_attr
-    /// [`Stream::new_extended()`]: super::Stream::new_extended
-    /// [`Info`]: crate::format::Info
-    /// [`Info::new_from_sample_spec()`]: crate::format::Info::new_from_sample_spec
-    pub const FIX_FORMAT: FlagSet = FlagSet::FIX_FORMAT;
-
-    /// Use the sample rate of the sink, and possibly ignore the rate the sample spec contains.
-    /// Usage similar to [`FIX_FORMAT`].
-    ///
-    /// When creating streams with [`Stream::new_extended()`], this flag has no effect. If you
-    /// specify a format with PCM encoding, and you want the server to choose the sample rate, then
-    /// you should leave the rate unspecified in the [`Info`] object. This also means that you can’t
-    /// use [`Info::new_from_sample_spec()`], because that function always sets the sample rate.
-    ///
-    /// [`FIX_FORMAT`]: constant.FIX_FORMAT.html
-    /// [`Stream::new_extended()`]: super::Stream::new_extended
-    /// [`Info`]: crate::format::Info
-    /// [`Info::new_from_sample_spec()`]: crate::format::Info::new_from_sample_spec
-    pub const FIX_RATE: FlagSet = FlagSet::FIX_RATE;
-
-    /// Use the number of channels and the channel map of the sink, and possibly ignore the number
-    /// of channels and the map the sample spec and the passed channel map contains. Usage similar
-    /// to [`FIX_FORMAT`].
-    ///
-    /// When creating streams with [`Stream::new_extended()`], this flag has no effect. If you
-    /// specify a format with PCM encoding, and you want the server to choose the channel count
-    /// and/or channel map, then you should leave the channels and/or the channel map unspecified in
-    /// the [`Info`] object. This also means that you can’t use [`Info::new_from_sample_spec()`],
-    /// because that function always sets the channel count (but if you only want to leave the
-    /// channel map unspecified, then [`Info::new_from_sample_spec()`] works, because the channel
-    /// map parameter is optional).
-    ///
-    /// [`FIX_FORMAT`]: constant.FIX_FORMAT.html
-    /// [`Stream::new_extended()`]: super::Stream::new_extended
-    /// [`Info`]: crate::format::Info
-    /// [`Info::new_from_sample_spec()`]: crate::format::Info::new_from_sample_spec
-    pub const FIX_CHANNELS: FlagSet = FlagSet::FIX_CHANNELS;
-
-    /// Don’t allow moving of this stream to another sink/device. Useful if you use any of the
-    /// `Fix*` flags and want to make sure that resampling never takes place -- which might happen
-    /// if the stream is moved to another sink/source with a different sample spec/channel map.
-    pub const DONT_MOVE: FlagSet = FlagSet::DONT_MOVE;
-
-    /// Allow dynamic changing of the sampling rate during playback with
-    /// [`Stream::update_sample_rate()`].
-    ///
-    /// [`Stream::update_sample_rate()`]: super::Stream::update_sample_rate
-    pub const VARIABLE_RATE: FlagSet = FlagSet::VARIABLE_RATE;
-
-    /// Find peaks instead of resampling.
-    pub const PEAK_DETECT: FlagSet = FlagSet::PEAK_DETECT;
-
-    /// Create in muted state. If neither [`START_UNMUTED`] nor this is specified, it is left to the
-    /// server to decide whether to create the stream in muted or in un-muted state.
-    pub const START_MUTED: FlagSet = FlagSet::START_MUTED;
-
-    /// Try to adjust the latency of the sink/source based on the requested buffer metrics and
-    /// adjust buffer metrics accordingly. Also see [`BufferAttr`]. This option may not be
-    /// specified at the same time as [`EARLY_REQUESTS`].
-    ///
-    /// [`BufferAttr`]: crate::def::BufferAttr
-    pub const ADJUST_LATENCY: FlagSet = FlagSet::ADJUST_LATENCY;
-
-    /// Enable compatibility mode for legacy clients that rely on a “classic” hardware device
-    /// fragment-style playback model. If this option is set, the `minreq` value of the buffer
-    /// metrics gets a new meaning: instead of just specifying that no requests asking for less new
-    /// data than this value will be made to the client it will also guarantee that requests are
-    /// generated as early as this limit is reached. This flag should only be set in very few
-    /// situations where compatibility with a fragment-based playback model needs to be kept and the
-    /// client applications cannot deal with data requests that are delayed to the latest moment
-    /// possible. (Usually these are programs that use usleep() or a similar call in their playback
-    /// loops instead of sleeping on the device itself.) Also see [`BufferAttr`]. This option may
-    /// not be specified at the same time as [`ADJUST_LATENCY`].
-    ///
-    /// [`BufferAttr`]: crate::def::BufferAttr
-    pub const EARLY_REQUESTS: FlagSet = FlagSet::EARLY_REQUESTS;
-
-    /// If set this stream won’t be taken into account when it is checked whether the device this
-    /// stream is connected to should auto-suspend.
-    pub const DONT_INHIBIT_AUTO_SUSPEND: FlagSet = FlagSet::DONT_INHIBIT_AUTO_SUSPEND;
-
-    /// Create in unmuted state. If neither [`START_MUTED`] nor this is specified, it is left to the
-    /// server to decide whether to create the stream in muted or in unmuted state.
-    pub const START_UNMUTED: FlagSet = FlagSet::START_UNMUTED;
-
-    /// If the sink/source this stream is connected to is suspended during the creation of this
-    /// stream, cause it to fail. If the sink/source is being suspended during creation of this
-    /// stream, make sure this stream is terminated.
-    pub const FAIL_ON_SUSPEND: FlagSet = FlagSet::FAIL_ON_SUSPEND;
-
-    /// If a volume is passed when this stream is created, consider it relative to the sink’s
-    /// current volume, never as absolute device volume. If this is not specified the volume will be
-    /// consider absolute when the sink is in flat volume mode, relative otherwise.
-    pub const RELATIVE_VOLUME: FlagSet = FlagSet::RELATIVE_VOLUME;
-
-    /// Used to tag content that will be rendered by passthrough sinks. The data will be left as is
-    /// and not reformatted, resampled.
-    pub const PASSTHROUGH: FlagSet = FlagSet::PASSTHROUGH;
-}
-
 /// Common event names supplied to the [`Stream::set_event_callback()`] callback.
 pub mod event_names {
     use capi;
@@ -721,7 +557,7 @@ impl Stream {
     {
         // Warning: New CStrings will be immediately freed if not bound to a variable, leading to
         // as_ptr() giving dangling pointers!
-        let c_name = CString::new(name.clone()).unwrap();
+        let c_name = CString::new(name).unwrap();
 
         let p_map = map.map_or(null::<capi::pa_channel_map>(), |m| m.as_ref());
 
@@ -747,7 +583,7 @@ impl Stream {
     {
         // Warning: New CStrings will be immediately freed if not bound to a variable, leading to
         // as_ptr() giving dangling pointers!
-        let c_name = CString::new(name.clone()).unwrap();
+        let c_name = CString::new(name).unwrap();
 
         let p_map = map.map_or(null::<capi::pa_channel_map>(), |m| m.as_ref());
 
@@ -767,6 +603,8 @@ impl Stream {
     /// While connecting, the server will select the most appropriate format which the client must
     /// then provide.
     ///
+    /// Will panic if the `formats` array is longer than can be communicated to the C function.
+    ///
     /// # Params
     ///
     /// * `ctx`: The context to create this stream in
@@ -776,9 +614,10 @@ impl Stream {
     pub fn new_extended(ctx: &mut Context, name: &str, formats: &[&format::Info],
         proplist: &mut Proplist) -> Option<Self>
     {
+        assert!(formats.len() <= u32::MAX as usize);
         // Warning: New CStrings will be immediately freed if not bound to a variable, leading to
         // as_ptr() giving dangling pointers!
-        let c_name = CString::new(name.clone()).unwrap();
+        let c_name = CString::new(name).unwrap();
 
         // Create array of format::InfoInternal pointers from provided array of `Info` pointers.
         let mut info_ptrs: Vec<*const capi::pa_format_info> = Vec::with_capacity(formats.len());
@@ -918,7 +757,7 @@ impl Stream {
         // Warning: New CStrings will be immediately freed if not bound to a variable, leading to
         // as_ptr() giving dangling pointers!
         let c_dev = match dev {
-            Some(dev) => CString::new(dev.clone()).unwrap(),
+            Some(dev) => CString::new(dev).unwrap(),
             None => CString::new("").unwrap(),
         };
 
@@ -949,7 +788,7 @@ impl Stream {
         // Warning: New CStrings will be immediately freed if not bound to a variable, leading to
         // as_ptr() giving dangling pointers!
         let c_dev = match dev {
-            Some(dev) => CString::new(dev.clone()).unwrap(),
+            Some(dev) => CString::new(dev).unwrap(),
             None => CString::new("").unwrap(),
         };
 
@@ -1428,34 +1267,37 @@ impl Stream {
 
     /// Pauses playback of this stream temporarily.
     ///
-    /// Available on both playback and recording streams.
+    /// This simply calls [`set_corked_state()`] with a value of `true`.
     ///
-    /// The pause operation is executed as quickly as possible. If a cork is very quickly followed
-    /// by an uncork, this might not actually have any effect on the stream that is output. You can
-    /// use [`is_corked()`] to find out whether the stream is currently paused or not. Normally a
-    /// stream will be created in uncorked state. If you pass [`FlagSet::START_CORKED`] as a flag
-    /// when connecting the stream, it will be created in corked state.
-    ///
-    /// The optional callback must accept a `bool`, which indicates success.
-    ///
-    /// Panics if the underlying C function returns a null pointer.
-    ///
-    /// [`is_corked()`]: Self::is_corked
+    /// [`set_corked_state()`]: Self::set_corked_state
+    #[inline(always)]
     pub fn cork(&mut self, callback: Option<Box<dyn FnMut(bool) + 'static>>)
         -> Operation<dyn FnMut(bool)>
     {
-        let (cb_fn, cb_data): (Option<extern "C" fn(_, _, _)>, _) =
-            get_su_capi_params::<_, _>(callback, success_cb_proxy);
-        let ptr = unsafe { capi::pa_stream_cork(self.ptr, true as i32, cb_fn, cb_data) };
-        Operation::from_raw(ptr, cb_data as *mut Box<dyn FnMut(bool)>)
+        self.set_corked_state(true, callback)
     }
 
     /// Resumes playback of this stream.
     ///
+    /// This simply calls [`set_corked_state()`] with a value of `false`.
+    ///
+    /// [`set_corked_state()`]: Self::set_corked_state
+    #[inline(always)]
+    pub fn uncork(&mut self, callback: Option<Box<dyn FnMut(bool) + 'static>>)
+        -> Operation<dyn FnMut(bool)>
+    {
+        self.set_corked_state(false, callback)
+    }
+
+    /// Pauses or resumes playback of this stream.
+    ///
     /// Available on both playback and recording streams.
     ///
-    /// The un-pause operation is executed as quickly as possible. If an uncork is very quickly
-    /// followed by a cork, this might not actually have any effect on the stream that is output.
+    /// Set state to `true` to cork (pause) the stream. Set state to `false` to uncork (resume) the
+    /// stream. Alternatively [`cork()`] and [`uncork()`] helper functions can be used.
+    ///
+    /// The operation is executed as quickly as possible. If a cork is very quickly followed by an
+    /// uncork, or vice versa, this might not actually have any effect on the stream that is output.
     /// You can use [`is_corked()`] to find out whether the stream is currently paused or not.
     /// Normally a stream will be created in uncorked state. If you pass [`FlagSet::START_CORKED`]
     /// as a flag when connecting the stream, it will be created in corked state.
@@ -1465,12 +1307,14 @@ impl Stream {
     /// Panics if the underlying C function returns a null pointer.
     ///
     /// [`is_corked()`]: Self::is_corked
-    pub fn uncork(&mut self, callback: Option<Box<dyn FnMut(bool) + 'static>>)
+    /// [`cork()`]: Self::cork
+    /// [`uncork()`]: Self::uncork
+    pub fn set_corked_state(&mut self, state: bool, callback: Option<Box<dyn FnMut(bool) + 'static>>)
         -> Operation<dyn FnMut(bool)>
     {
         let (cb_fn, cb_data): (Option<extern "C" fn(_, _, _)>, _) =
             get_su_capi_params::<_, _>(callback, success_cb_proxy);
-        let ptr = unsafe { capi::pa_stream_cork(self.ptr, false as i32, cb_fn, cb_data) };
+        let ptr = unsafe { capi::pa_stream_cork(self.ptr, state as i32, cb_fn, cb_data) };
         Operation::from_raw(ptr, cb_data as *mut Box<dyn FnMut(bool)>)
     }
 
@@ -1538,7 +1382,7 @@ impl Stream {
     {
         // Warning: New CStrings will be immediately freed if not bound to a
         // variable, leading to as_ptr() giving dangling pointers!
-        let c_name = CString::new(name.clone()).unwrap();
+        let c_name = CString::new(name).unwrap();
 
         let (cb_fn, cb_data): (Option<extern "C" fn(_, _, _)>, _) =
             get_su_capi_params::<_, _>(callback, success_cb_proxy);
